Applying summary on an object of class surerob
returns a list of class summary.surerob.
An object of class summary.surerob
contains all results that belong to the whole system.
This list contains one special object: eq.
This is a list and contains objects of class
summary.lmrob.
These objects contain the results that belong to each of the estimated equations.
The objects of classes summary.surerob
have the following components
- method
estimation method.
- residuals
residuals.
- residCovEst
residual covariance matrix used for estimation.
- residCov
estimated residual covariance matrix.
- residCor
correlation matrix of the residuals.
- detResidCov
determinant of residCov.
- rweights
matrix of robust weights.
- eq
a list containing the summary from function
summary.lmrob and ssr: residual
sum of squares, eqnNo: equation number and eqnLabel:
equation label.
- df
degrees of freedom, a 2-vector, where the first element is
the number of coefficients and the second element is the number of
observations minus the number of coefficients.
- coefficients
a matrix with columns for the estimated coefficients,
their standard errors, t-statistic and corresponding (two-sided) p-values.
- ssr_weighted
weighted residual sum of squares.
- r.squared
\(R^2\) value.
- adj.r.squared
adjusted \(R^2\) value.
- coefCov
estimated covariance matrix of the coefficients.
- printResidCov
argument residCov.
- printEquations
argument equations.
- control
list of control parameters used for the estimation.
- call
the matched call of surerob.